//
// Copyright 2012 Twitter
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

Backbone.Events.bind('clutch.initialized', function() {

// This is the global-ish variable where the user will be stored
var USER = null;

// Used to display a single image thumbnail on the thumbnail page
var ImageThumb = Clutch.UI.View.extend({
    tagName: 'li',
    template: _.template($('#template-image-thumb').html()),
    events: {
        'tap': 'handleTap'
    },
    handleTap: function(e) {
        Clutch.Core.callMethod('imageThumbnailTapped', this.options.image);
    }
});

// Used to display an image "feed" entry, with some comments and likes etc.
var ImageDetail = Clutch.UI.View.extend({
    tagName: 'li',
    template: _.template($('#template-image-detail').html()),
    events: {
        'tap img.main': 'imageTapped',
        'tap a.like': 'likeTapped',
        'tap a.comment': 'commentTapped',
        'tap a.more': 'moreTapped',
        'tap a.like-summary': 'likeSummaryTapped',
        'tap a.comment-detail': 'commentDetailTapped',
        'click': 'preventClicks'
    },
    imageTapped: function(e) {
        Clutch.Core.callMethod('imagePopup', this.options.image);
    },
    likeTapped: function(e) {
        // First tell iOS that they tapped the image
        Clutch.Core.callMethod('likeTapped', this.options.image);

        // If they weren't logged in, then we know iOS kicked them to a login
        // screen, so just bail.
        if(!USER) {
            return;
        }

        // Otherwise they were logged in, make the change
        var created = _.pluck(this.options.image.likes, 'id').indexOf(USER.id) === -1;
        if(created) {
            this.options.image.likes.push(USER);
        } else {
            this.options.image.likes = _.reject(this.options.image.likes, function(user) {
                return user.id === USER.id;
            });
        }
        this.render();
    },
    likeSummaryTapped: function(e) {
        Clutch.Core.callMethod('likeSummaryTapped', this.options.image);
    },
    commentDetailTapped: function(e) {
        Clutch.Core.callMethod('imageThumbnailTapped', this.options.image);
    },
    commentTapped: function(e) {
        Clutch.Core.callMethod('commentTapped', this.options.image, _.bind(function(data) {
            this.options.image.comments.push({
                user: USER,
                text: data.text
            });
            this.render();
        }, this));
    },
    moreTapped: function(e) {
        Clutch.Core.callMethod('moreTapped', this.options.image);
    },
    preventClicks: function(e) {
        e.stopPropagation();
        e.preventDefault();
    },
    render: function(force) {
        // Determine whether this user liked this image, for use in the
        // template context.
        var liked;
        if(USER) {
            liked = _.pluck(this.options.image.likes, 'id').indexOf(USER.id) !== -1;
        } else {
            liked = false;
        }

        // Render the template to this element
        $(this.el).html(this.template({
            user: USER,
            c: this.options,
            liked: liked
        }));

        return this;
    }
});

// Handles the rendering of a list of images to the screen
var ImageList = Clutch.UI.View.extend({
    tagName: 'ul',
    initialize: function(options) {
        Clutch.UI.View.prototype.initialize.call(this, options);

        // Reset the start and end indexes at the outset
        this.reset();

        // We bind 'this' to the following functions
        _.bindAll(this, 'getUrl', 'addImages', 'reset', 'page');
    },
    addImages: function() {
        // Cache access to the Zepto'd this.el so we don't have to recreate it a lot
        var elt = $(this.el);

        // Based on the display type, choose either ImageThumb or ImageDetail
        var imageClass = this.options.displayType === 'thumb' ? ImageThumb : ImageDetail;

        // Render entries from start to end (either 10 or 32 based on display type)
        for(var i = this.options.start; i < this.options.end; ++i) {
            var imageData = this.options.data.gallery[i];
            if(!imageData) {
                break;
            }
            var image = new imageClass({image: imageData});
            elt.append(image.render().el);
        }
    },
    reset: function() {
        this.options.start = 0;
        this.options.end = this.options.displayType === 'thumb' ? 32 : 10;
        $(this.el).html('');
        return this;
    },
    render: function() {
        this.el.className = (
            'kind-' + this.options.kind + ' ' +
            'display-' + this.options.displayType
        );
        this.addImages(this.options.data.gallery);
        return this;
    },
    page: function() {
        var delta = this.options.end - this.options.start;
        this.options.start += delta;
        this.options.end += delta;
    },
    getUrl: function() {
        return 'http://imgur.com/gallery/' + this.options.kind + '/all/page/0.json';
    }
});

var ShowMoreButton = Clutch.UI.View.extend({
    tagName: 'a',
    className: 'show-more',
    template: _.template('Show More'),
    events: {
        'tap': 'handleTap',
        'click': 'handleTap'
    },
    handleTap: function(e) {
        $(this.el).text('Loading...').addClass('loading');

        // Prevent double-clicks
        if(this.timeout) {
            return;
        }

        this.timeout = setTimeout(_.bind(function() {
            delete this.timeout;
            IMAGES.page();
            IMAGES.addImages();
            $(this.el).text('Show More').removeClass('loading');
            if(!IMAGES.options.data.gallery[IMAGES.options.end + 1]) {
                $(this.el).addClass('hide');
            }
        }, this), 50);
    },
    handleClick: function(e) {
        e.stopPropagation();
        e.preventDefault();
        return false;
    }
});

// Gets a parameter from the page's query string
function getParameterByName(name) {
    var match = RegExp('[?&]' + name + '=([^&]*)').exec(window.location.search);
    return match && decodeURIComponent(match[1].replace(/\+/g, ' '));
}

var IMAGES = new ImageList({
    kind: 'hot',
    displayType: getParameterByName('displayType') || 'thumb'
});

// Handles the fetching of imgur data through iOS
function getImgurData() {
    Clutch.Core.callMethod('imgurRequest', {'url': IMAGES.getUrl()}, function(data) {
        if(data.data) {
            var gallery = _.filter(data.data.gallery, function(item) {
                // Filter out animated gifs (well, all gifs since we can't
                // know which ones are animated in advance.)
                if(item.ext === '.gif') {
                    return false;
                }
                // Filter out all extremely wide or extremely tall images
                var ratio = Math.abs(item.height / item.width);
                if(ratio > 2 || ratio < 0.4) {
                    return false;
                }
                return true;
            });
            IMAGES.options.data = {gallery: gallery};
            $('#photos').html(IMAGES.render().el);
            var showMore = new ShowMoreButton();
            $('#photos').after(showMore.render().el);
        } else {
            // TODO: Handle no internet or bad API call
        }
        Clutch.Load.end();
    });
}

Clutch.Core.registerMethod('setUser', function(data) {
    USER = data;
});

if(Clutch.iOS) {
    Clutch.Load.begin();
    Clutch.Core.callMethod('getInitialData', function(data) {
        IMAGES.options.kind = data.kind;
        IMAGES.options.displayType = data.displayType;
        IMAGES.reset();
        if(data.user) {
            USER = data.user;
        }
        getImgurData();
    });
} else {
    IMAGES.options.data = {"gallery":[{"hash":"VcBfl","title":"Andy and April's list of places to live from Parks and Rec.","score":467610,"size":72881,"views":77610,"datetime":"2012-10-03 00:14:20","mimetype":"image\/jpeg","ext":".jpg","width":1366,"height":768,"ups":41,"downs":2,"points":39,"reddit":"\/r\/gameofthrones\/comments\/10tck8\/andy_and_aprils_list_of_places_to_live_from_parks\/","firstpost_date":1349223260,"bandwidth":"5.27 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"m5kAg","title":"Excellent teamwork","score":656092,"size":1015808,"views":6092,"datetime":"2012-10-03 00:09:02","mimetype":"image\/gif","ext":".gif","width":300,"height":271,"ups":66,"downs":1,"points":65,"reddit":"\/r\/gifs\/comments\/10tzu9\/excellent_teamwork\/","firstpost_date":1349222942,"bandwidth":"5.76 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Nuo9X","title":"33 saw this and thought of you and all of the pictures of her at the damn club","score":1309849,"size":170302,"views":369849,"datetime":"2012-10-03 00:04:42","mimetype":"image\/jpeg","ext":".jpg","width":800,"height":1053,"ups":115,"downs":21,"points":94,"reddit":"\/r\/pics\/comments\/10trkt\/this_woman_is_48_years_old_mary_louise_parker_is\/","firstpost_date":1349222682,"bandwidth":"58.66 GB","source":"http:\/\/stolenmoments911.files.wordpress.com\/2010\/07\/mary-louise-parker-nude-esquire-01.jpg","gallery_timestamp":null,"vote":null},{"hash":"LQ1Sd","title":"Find the pea","score":696046,"size":1018656,"views":36046,"datetime":"2012-10-02 23:58:56","mimetype":"image\/gif","ext":".gif","width":400,"height":224,"ups":66,"downs":0,"points":66,"reddit":"\/r\/gifs\/comments\/10tobj\/find_the_pea\/","firstpost_date":1349222336,"bandwidth":"34.20 GB","source":"http:\/\/media.tumblr.com\/tumblr_mb2fkzCFo71qlkly8.gif","gallery_timestamp":null,"vote":null},{"hash":"iO2jz","title":"Iron-girl","score":689793,"size":67570,"views":59793,"datetime":"2012-10-02 23:58:56","mimetype":"image\/jpeg","ext":".jpg","width":720,"height":960,"ups":64,"downs":1,"points":63,"reddit":"\/r\/pics\/comments\/10tlw8\/irongirl\/","firstpost_date":1349222336,"bandwidth":"3.76 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"9gyQk","title":"That is disgust","score":407497,"size":54245,"views":27497,"datetime":"2012-10-02 23:58:56","mimetype":"image\/jpeg","ext":".jpg","width":683,"height":969,"ups":43,"downs":5,"points":38,"reddit":"\/r\/pics\/comments\/10twmi\/that_is_disgust\/","firstpost_date":1349222336,"bandwidth":"1.39 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"rdfDr","title":"Canada's getting ready for winter.","score":642283,"size":607683,"views":22283,"datetime":"2012-10-02 23:50:45","mimetype":"image\/png","ext":".png","width":708,"height":682,"ups":63,"downs":1,"points":62,"reddit":"\/r\/pics\/comments\/10tnq9\/canadas_getting_ready_for_winter\/","firstpost_date":1349221845,"bandwidth":"12.61 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"BsqRt","title":"I got to meet Thor, the god of thunder","score":952793,"size":647579,"views":82793,"datetime":"2012-10-02 23:50:45","mimetype":"image\/jpeg","ext":".jpg","width":3648,"height":2736,"ups":88,"downs":1,"points":87,"reddit":"\/r\/pics\/comments\/10tue6\/i_got_to_meet_thor_the_god_of_thunder\/","firstpost_date":1349221845,"bandwidth":"49.93 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"TVK1W","title":"I don't operate very well under sexual tension...","score":1108919,"size":79603,"views":8919,"datetime":"2012-10-02 23:34:44","mimetype":"image\/jpeg","ext":".jpg","width":576,"height":577,"ups":116,"downs":6,"points":110,"reddit":"\/r\/AdviceAnimals\/comments\/10u21m\/i_dont_operate_very_well_under_sexual_tension\/","firstpost_date":1349220884,"bandwidth":"677.09 MB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"0DhXa","title":"Asked my friend for a intense painting .","score":1118442,"size":97055,"views":128442,"datetime":"2012-10-02 23:34:44","mimetype":"image\/jpeg","ext":".jpg","width":479,"height":960,"ups":105,"downs":6,"points":99,"reddit":"\/r\/pics\/comments\/10ts9v\/asked_my_friend_for_a_intense_painting\/","firstpost_date":1349220884,"bandwidth":"11.61 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ZcIOx","title":"I present to you - the canine race of Skyrim - Dogmer","score":1046839,"size":62366,"views":56839,"datetime":"2012-10-02 23:13:41","mimetype":"image\/jpeg","ext":".jpg","width":610,"height":343,"ups":102,"downs":3,"points":99,"reddit":"\/r\/skyrim\/comments\/10tkuz\/i_present_to_you_the_canine_race_of_skyrim_dogmer\/","firstpost_date":1349219621,"bandwidth":"3.30 GB","source":"http:\/\/media.pcgamer.com\/files\/2012\/10\/Skyrim-Crimes-Against-Nature-1-610x343.jpg","gallery_timestamp":null,"vote":null},{"hash":"9zrzQ","title":"Tyrone is getting his shit together","score":1422610,"size":35853,"views":102610,"datetime":"2012-10-02 23:08:19","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":598,"ups":137,"downs":5,"points":132,"reddit":"\/r\/pics\/comments\/10tnvg\/tyrone_is_getting_his_shit_together\/","firstpost_date":1349219299,"bandwidth":"3.43 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"qtlQI","title":"Breakfast with Tina","score":1804189,"size":533822,"views":64189,"datetime":"2012-10-02 23:03:14","mimetype":"image\/png","ext":".png","width":450,"height":673,"ups":190,"downs":16,"points":174,"reddit":"\/r\/pics\/comments\/10tm63\/breakfast_with_tina\/","firstpost_date":1349218994,"bandwidth":"31.91 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"jrhdz","title":"Happy Anniversary","score":2122628,"size":56931,"views":102628,"datetime":"2012-10-02 22:59:26","mimetype":"image\/jpeg","ext":".jpg","width":302,"height":596,"ups":206,"downs":4,"points":202,"reddit":"\/r\/funny\/comments\/10tm01\/happy_anniversary\/","firstpost_date":1349218766,"bandwidth":"5.44 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"iFvFE","title":"Tiger cub on a dog","score":1622070,"size":186573,"views":92070,"datetime":"2012-10-02 22:53:18","mimetype":"image\/jpeg","ext":".jpg","width":700,"height":522,"ups":155,"downs":2,"points":153,"reddit":"\/r\/aww\/comments\/10tffg\/tiger_cub_on_a_dog\/","firstpost_date":1349218398,"bandwidth":"16.00 GB","source":"http:\/\/a1.vsoh.com\/ff35de55.jpg","gallery_timestamp":null,"vote":null},{"hash":"PEbEN","title":"Oh the irony","score":2027679,"size":507067,"views":67679,"datetime":"2012-10-02 22:38:44","mimetype":"image\/gif","ext":".gif","width":250,"height":151,"ups":200,"downs":4,"points":196,"reddit":"\/r\/gifs\/comments\/10t817\/oh_the_irony\/","firstpost_date":1349217524,"bandwidth":"31.96 GB","source":"http:\/\/25.media.tumblr.com\/tumblr_lo73d1AuwU1qghhwyo1_250.gif","gallery_timestamp":null,"vote":null},{"hash":"P0sat","title":"Still better actor than Kristen Stewart","score":2275553,"size":2085416,"views":165553,"datetime":"2012-10-02 22:30:00","mimetype":"image\/gif","ext":".gif","width":364,"height":191,"ups":220,"downs":9,"points":211,"reddit":"\/r\/funny\/comments\/10tk00\/still_better_actor_than_kristen_stewart\/","firstpost_date":1349217000,"bandwidth":"321.54 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"G062d","title":"heh","score":1226406,"size":161552,"views":176406,"datetime":"2012-10-02 22:13:47","mimetype":"image\/png","ext":".png","width":360,"height":420,"ups":142,"downs":37,"points":105,"reddit":"\/r\/funny\/comments\/10thyr\/heh\/","firstpost_date":1349216027,"bandwidth":"26.54 GB","source":"http:\/\/i252.photobucket.com\/albums\/hh30\/ANGELPERRY1\/humor-2.png","gallery_timestamp":null,"vote":null},{"hash":"DDjaX","title":"Good Guy 4Chan","score":2111772,"size":365643,"views":61772,"datetime":"2012-10-02 22:09:46","mimetype":"image\/png","ext":".png","width":1214,"height":678,"ups":218,"downs":13,"points":205,"reddit":"\/r\/4chan\/comments\/10tu35\/good_guy_4chan\/","firstpost_date":1349215786,"bandwidth":"21.04 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"9Jb5z","title":"Zach Braff on Abortion","score":1937388,"size":83737,"views":207388,"datetime":"2012-10-02 22:09:46","mimetype":"image\/jpeg","ext":".jpg","width":1024,"height":801,"ups":210,"downs":37,"points":173,"reddit":"\/r\/funny\/comments\/10tii0\/zach_braff_on_abortion\/","firstpost_date":1349215786,"bandwidth":"16.17 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"i40uY","title":"Into the blue","score":2139278,"size":86845,"views":169278,"datetime":"2012-10-02 22:03:26","mimetype":"image\/jpeg","ext":".jpg","width":480,"height":750,"ups":199,"downs":2,"points":197,"reddit":"\/r\/pics\/comments\/10tkiq\/into_the_blue\/","firstpost_date":1349215406,"bandwidth":"13.69 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"5qUfN","title":"Rosa Parks","score":2796387,"size":9703,"views":156387,"datetime":"2012-10-02 22:03:25","mimetype":"image\/png","ext":".png","width":609,"height":199,"ups":281,"downs":17,"points":264,"reddit":"\/r\/funny\/comments\/10tq0l\/rosa_parks\/","firstpost_date":1349215405,"bandwidth":"1.41 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Hgjor","title":"Chain Letter (FB)","score":2718251,"size":23464,"views":138251,"datetime":"2012-10-02 21:55:28","mimetype":"image\/png","ext":".png","width":526,"height":125,"ups":293,"downs":35,"points":258,"reddit":"\/r\/funny\/comments\/10txig\/chain_letter_fb\/","firstpost_date":1349214928,"bandwidth":"3.02 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"6nMUE","title":"Beautiful carved temples in Madurai, India","score":3358034,"size":259618,"views":188034,"datetime":"2012-10-02 21:37:45","mimetype":"image\/jpeg","ext":".jpg","width":1152,"height":864,"ups":319,"downs":2,"points":317,"reddit":"\/r\/pics\/comments\/10tnar\/beautiful_carved_temples_in_madurai_india\/","firstpost_date":1349213865,"bandwidth":"45.46 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"bLJim","title":"Survivorman's \"subtle\" dig at Bear Grylls","score":2706363,"size":241983,"views":176363,"datetime":"2012-10-02 21:18:24","mimetype":"image\/jpeg","ext":".jpg","width":481,"height":1000,"ups":272,"downs":19,"points":253,"reddit":"\/r\/funny\/comments\/10tn4r\/survivormans_subtle_dig_at_bear_grylls\/","firstpost_date":1349212704,"bandwidth":"39.75 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ojvAH","title":"missed it by that much","score":1674965,"size":2091518,"views":74965,"datetime":"2012-10-02 21:13:58","mimetype":"image\/gif","ext":".gif","width":311,"height":259,"ups":163,"downs":3,"points":160,"reddit":"\/r\/gifs\/comments\/10tb9z\/missed_it_by_that_much\/","firstpost_date":1349212438,"bandwidth":"146.02 GB","source":"http:\/\/forgifs.com\/gallery\/d\/132358-1\/Football_field_goal_fail.gif","gallery_timestamp":null,"vote":null},{"hash":"NhGIW","title":"With all due respect to Gary Larson, \"If we pull this off, we'll eat like kings.\"","score":2691446,"size":582208,"views":211446,"datetime":"2012-10-02 21:08:18","mimetype":"image\/jpeg","ext":".jpg","width":2592,"height":1936,"ups":253,"downs":5,"points":248,"reddit":"\/r\/pics\/comments\/10tftj\/with_all_due_respect_to_gary_larson_if_we_pull\/","firstpost_date":1349212098,"bandwidth":"114.65 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"kKYs1","title":"All in one week","score":3038263,"size":105529,"views":255530,"datetime":"2012-10-02 21:08:18","mimetype":"image\/jpeg","ext":".jpg","width":310,"height":1225,"ups":294,"downs":14,"points":280,"reddit":"\/r\/pics\/comments\/10thhe\/all_in_one_week\/","firstpost_date":1349212098,"bandwidth":"25.11 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"arLeh","title":"Nothing Really Mattress...(I pass this on my drive to work every day.)","score":1895023,"size":104197,"views":215023,"datetime":"2012-10-02 21:04:07","mimetype":"image\/jpeg","ext":".jpg","width":612,"height":612,"ups":171,"downs":3,"points":168,"reddit":"\/r\/pics\/comments\/10thnl\/nothing_really_mattressi_pass_this_on_my_drive_to\/","firstpost_date":1349211847,"bandwidth":"20.87 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"irmt8","title":"legit?","score":2203878,"size":2095398,"views":123878,"datetime":"2012-10-02 20:58:14","mimetype":"image\/gif","ext":".gif","width":310,"height":241,"ups":210,"downs":2,"points":208,"reddit":"\/r\/gifs\/comments\/10tf4j\/legit\/","firstpost_date":1349211494,"bandwidth":"241.75 GB","source":"http:\/\/forgifs.com\/gallery\/d\/131977-1\/Football_catch_reception.gif","gallery_timestamp":null,"vote":null},{"hash":"dOkmS","title":"Like a glove","score":2591076,"size":1313862,"views":331076,"datetime":"2012-10-02 20:45:23","mimetype":"image\/gif","ext":".gif","width":282,"height":168,"ups":227,"downs":1,"points":226,"reddit":"\/r\/funny\/comments\/10ti4n\/like_a_glove\/","firstpost_date":1349210723,"bandwidth":"405.11 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"juX7y","title":"100 likes...","score":2814137,"size":17337,"views":274137,"datetime":"2012-10-02 20:33:35","mimetype":"image\/jpeg","ext":".jpg","width":513,"height":282,"ups":275,"downs":21,"points":254,"reddit":"\/r\/funny\/comments\/10tq2v\/100_likes\/","firstpost_date":1349210015,"bandwidth":"4.43 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"sCDa9","title":"Airline screwed up, a friend just posted this on Facebook.","score":8924961,"size":173132,"views":144961,"datetime":"2012-10-02 20:30:04","mimetype":"image\/png","ext":".png","width":380,"height":617,"ups":884,"downs":6,"points":878,"reddit":"\/r\/funny\/comments\/10tya8\/airline_screwed_up_a_friend_just_posted_this_on\/","firstpost_date":1349209804,"bandwidth":"23.37 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"HIo7D","title":"Don't look at it, touch it, or even think about it!\u00a0","score":3677277,"size":16636,"views":287277,"datetime":"2012-10-02 20:30:04","mimetype":"image\/jpeg","ext":".jpg","width":410,"height":424,"ups":346,"downs":7,"points":339,"reddit":"\/r\/funny\/comments\/10tck5\/dont_look_at_it_touch_it_or_even_think_about_it\/","firstpost_date":1349209804,"bandwidth":"4.45 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"A7pIY","title":"Asian crocodile pimp of muni","score":2883569,"size":97308,"views":243569,"datetime":"2012-10-02 20:30:04","mimetype":"image\/jpeg","ext":".jpg","width":768,"height":1024,"ups":266,"downs":2,"points":264,"reddit":"\/r\/funny\/comments\/10tk7l\/asian_crocodile_pimp_of_muni\/","firstpost_date":1349209804,"bandwidth":"22.07 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"GWkRk","title":"Best\/most realistic use of make up I've seen in a LONG time. (Levitt as young Bruce Willis in Looper)","score":3861193,"size":510626,"views":551193,"datetime":"2012-10-02 20:25:39","mimetype":"image\/png","ext":".png","width":650,"height":410,"ups":340,"downs":9,"points":331,"reddit":"\/r\/movies\/comments\/10tda4\/bestmost_realistic_use_of_make_up_ive_seen_in_a\/","firstpost_date":1349209539,"bandwidth":"262.12 GB","source":"http:\/\/2.bp.blogspot.com\/-L7Ul8zAYneE\/UCPPaBi057I\/AAAAAAAAEn8\/B8z3PYtvgOs\/s1600\/looper.png","gallery_timestamp":null,"vote":null},{"hash":"5EamK","title":"What it's like trying to bring humour to my inlaws.","score":3012029,"size":69182,"views":282029,"datetime":"2012-10-02 20:19:54","mimetype":"image\/jpeg","ext":".jpg","width":960,"height":692,"ups":283,"downs":10,"points":273,"reddit":"\/r\/funny\/comments\/10tll0\/what_its_like_trying_to_bring_humour_to_my_inlaws\/","firstpost_date":1349209194,"bandwidth":"18.17 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"5fAn4","title":"Going on r\/gonewild\/new","score":1412579,"size":485576,"views":362579,"datetime":"2012-10-02 20:13:23","mimetype":"image\/gif","ext":".gif","width":196,"height":181,"ups":125,"downs":20,"points":105,"reddit":"\/r\/funny\/comments\/10tjtc\/going_on_rgonewildnew\/","firstpost_date":1349208803,"bandwidth":"163.97 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"4arHG","title":"How to ruin someone's day","score":3358791,"size":246422,"views":318791,"datetime":"2012-10-02 20:13:23","mimetype":"image\/jpeg","ext":".jpg","width":1200,"height":629,"ups":312,"downs":8,"points":304,"reddit":"\/r\/funny\/comments\/10tizt\/how_to_ruin_someones_day\/","firstpost_date":1349208803,"bandwidth":"73.16 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"3Clec","title":"Einstein don't get caught looking","score":3139553,"size":40890,"views":309553,"datetime":"2012-10-02 20:08:41","mimetype":"image\/jpeg","ext":".jpg","width":568,"height":720,"ups":286,"downs":3,"points":283,"reddit":"\/r\/funny\/comments\/10tgf7\/einstein_dont_get_caught_looking\/","firstpost_date":1349208521,"bandwidth":"11.79 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Z2rc6","title":"The Bacon shortage is here.....now!!!!","score":1394972,"size":97437,"views":364972,"datetime":"2012-10-02 20:03:37","mimetype":"image\/jpeg","ext":".jpg","width":548,"height":765,"ups":160,"downs":57,"points":103,"reddit":"\/r\/funny\/comments\/10tjq6\/the_bacon_shortage_is_herenow\/","firstpost_date":1349208217,"bandwidth":"33.12 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"WRpDJ","title":"I'm so bored...","score":2715227,"size":85547,"views":335227,"datetime":"2012-10-02 19:53:46","mimetype":"image\/jpeg","ext":".jpg","width":1200,"height":903,"ups":241,"downs":3,"points":238,"reddit":"\/r\/funny\/comments\/10tfw2\/im_so_bored\/","firstpost_date":1349207626,"bandwidth":"26.71 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"jh1LO","title":"My girlfriend at an audition. I'm not threatened...","score":2917565,"size":462,"views":217565,"datetime":"2012-10-02 19:48:07","mimetype":"image\/jpeg","ext":".jpg","width":165,"height":33,"ups":273,"downs":3,"points":270,"reddit":"\/r\/funny\/comments\/10tpan\/my_girlfriend_at_an_audition_im_not_threatened\/","firstpost_date":1349207287,"bandwidth":"95.86 MB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"VEUug","title":"Roommate hid this photo of himself in my laptop as a joke. Bring him immediate regret.","score":3119354,"size":657288,"views":409354,"datetime":"2012-10-02 19:42:46","mimetype":"image\/jpeg","ext":".jpg","width":2884,"height":2374,"ups":276,"downs":5,"points":271,"reddit":"\/r\/funny\/comments\/10tltz\/roommate_hid_this_photo_of_himself_in_my_laptop\/","firstpost_date":1349206966,"bandwidth":"250.58 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ut69x","title":"MTV","score":3622068,"size":27796,"views":292068,"datetime":"2012-10-02 19:40:34","mimetype":"image\/jpeg","ext":".jpg","width":460,"height":573,"ups":343,"downs":10,"points":333,"reddit":"\/r\/funny\/comments\/10th3m\/mtv\/","firstpost_date":1349206834,"bandwidth":"7.56 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"uQaqw","title":"I see your German Shepherd and raise you a German Shepherd.","score":4375924,"size":190604,"views":165924,"datetime":"2012-10-02 19:40:34","mimetype":"image\/jpeg","ext":".jpg","width":1019,"height":792,"ups":423,"downs":2,"points":421,"reddit":"\/r\/pics\/comments\/10t5n9\/i_see_your_german_shepherd_and_raise_you_a_german\/","firstpost_date":1349206834,"bandwidth":"29.45 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"tmow7","title":"And other poems by cats...","score":3629564,"size":556290,"views":229564,"datetime":"2012-10-02 19:40:34","mimetype":"image\/jpeg","ext":".jpg","width":1936,"height":2592,"ups":345,"downs":5,"points":340,"reddit":"\/r\/funny\/comments\/10tfkj\/and_other_poems_by_cats\/","firstpost_date":1349206834,"bandwidth":"118.93 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"JOeJn","title":"not bad","score":3668927,"size":2078516,"views":178927,"datetime":"2012-10-02 19:40:34","mimetype":"image\/gif","ext":".gif","width":292,"height":220,"ups":350,"downs":1,"points":349,"reddit":"\/r\/gifs\/comments\/10tb7z\/not_bad\/","firstpost_date":1349206834,"bandwidth":"346.36 GB","source":"http:\/\/forgifs.com\/gallery\/d\/128442-2\/Kid_parallel_parking.gif","gallery_timestamp":null,"vote":null},{"hash":"0qQwe","title":"Can't tell if television has gotten better or worse.","score":2539855,"size":272896,"views":359855,"datetime":"2012-10-02 19:40:34","mimetype":"image\/jpeg","ext":".jpg","width":1600,"height":1086,"ups":224,"downs":6,"points":218,"reddit":"\/r\/funny\/comments\/10tkg0\/cant_tell_if_television_has_gotten_better_or_worse\/","firstpost_date":1349206834,"bandwidth":"91.46 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"zkVJb","title":"Oh, mercy me!","score":4858212,"size":55101,"views":318212,"datetime":"2012-10-02 19:33:15","mimetype":"image\/jpeg","ext":".jpg","width":475,"height":551,"ups":463,"downs":9,"points":454,"reddit":"\/r\/funny\/comments\/10toev\/oh_mercy_me\/","firstpost_date":1349206395,"bandwidth":"16.33 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ztvrE","title":"So my friend recently got a job at DQ.  This is the first thing she was asked to write on a cake.","score":3638979,"size":84470,"views":298979,"datetime":"2012-10-02 19:22:19","mimetype":"image\/jpeg","ext":".jpg","width":612,"height":612,"ups":335,"downs":1,"points":334,"reddit":"\/r\/funny\/comments\/10tkbz\/so_my_friend_recently_got_a_job_at_dq_this_is_the\/","firstpost_date":1349205739,"bandwidth":"23.52 GB","source":"https:\/\/sphotos-a.xx.fbcdn.net\/hphotos-snc6\/262360_113819375435812_1125540007_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"mwil7","title":"So I guess just don't go down there...","score":2603678,"size":706701,"views":256505,"datetime":"2012-10-02 19:20:54","mimetype":"image\/jpeg","ext":".jpg","width":2448,"height":3264,"ups":238,"downs":3,"points":235,"reddit":"\/r\/funny\/comments\/10t2bj\/so_i_guess_just_dont_go_down_there\/","firstpost_date":1349205654,"bandwidth":"168.82 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"k0pvp","title":"Movie night at my university.  (The Room)","score":1625650,"size":480403,"views":215650,"datetime":"2012-10-02 19:20:54","mimetype":"image\/jpeg","ext":".jpg","width":900,"height":1200,"ups":150,"downs":9,"points":141,"reddit":"\/r\/movies\/comments\/10tc12\/movie_night_at_my_university_the_room\/","firstpost_date":1349205654,"bandwidth":"96.48 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"iwrsq","title":"Missile launched.","score":2703485,"size":41235,"views":353485,"datetime":"2012-10-02 19:20:54","mimetype":"image\/jpeg","ext":".jpg","width":295,"height":800,"ups":237,"downs":2,"points":235,"reddit":"\/r\/funny\/comments\/10tehk\/missile_launched\/","firstpost_date":1349205654,"bandwidth":"13.57 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"EaJqu","title":"Mostly the latter","score":4516718,"size":33130,"views":446718,"datetime":"2012-10-02 19:15:23","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":344,"ups":410,"downs":3,"points":407,"reddit":"\/r\/funny\/comments\/10tloz\/mostly_the_latter\/","firstpost_date":1349205323,"bandwidth":"13.78 GB","source":"https:\/\/i.chzbgr.com\/completestore\/12\/9\/28\/-tXtYUFVtEKNLlMnC5HTXA2.jpg","gallery_timestamp":null,"vote":null},{"hash":"RTYr6","title":"How I feel talking to people who've seen all 8 movies","score":4460311,"size":64147,"views":80311,"datetime":"2012-10-02 19:04:00","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":500,"ups":449,"downs":11,"points":438,"reddit":"\/r\/harrypotter\/comments\/10s94w\/how_i_feel_talking_to_people_whove_seen_all_8\/","firstpost_date":1349204640,"bandwidth":"4.80 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"VFEmo","title":"Soon...","score":4254205,"size":57148,"views":344205,"datetime":"2012-10-02 18:59:11","mimetype":"image\/jpeg","ext":".jpg","width":900,"height":718,"ups":396,"downs":5,"points":391,"reddit":"\/r\/funny\/comments\/10tdan\/soon\/","firstpost_date":1349204351,"bandwidth":"18.32 GB","source":"https:\/\/sphotos-a.xx.fbcdn.net\/hphotos-snc6\/230485_302987226475925_1025790007_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"Vdud0","title":"Boba's Guilty face","score":1909488,"size":365367,"views":169488,"datetime":"2012-10-02 18:59:11","mimetype":"image\/jpeg","ext":".jpg","width":2448,"height":3264,"ups":183,"downs":9,"points":174,"reddit":"\/r\/aww\/comments\/10sxz8\/bobas_guilty_face\/","firstpost_date":1349204351,"bandwidth":"57.67 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"PcUP7","title":"Ted on Justin Bieber throwing up. (FB)","score":2382450,"size":428769,"views":312450,"datetime":"2012-10-02 18:49:52","mimetype":"image\/png","ext":".png","width":1024,"height":809,"ups":252,"downs":45,"points":207,"reddit":"\/r\/funny\/comments\/10tcil\/ted_on_justin_bieber_throwing_up_fb\/","firstpost_date":1349203792,"bandwidth":"124.77 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"36ink","title":"It's time... ESPN make this happen!","score":4450464,"size":112406,"views":550464,"datetime":"2012-10-02 18:43:13","mimetype":"image\/jpeg","ext":".jpg","width":1275,"height":744,"ups":405,"downs":15,"points":390,"reddit":"\/r\/funny\/comments\/10tjzq\/its_time_espn_make_this_happen\/","firstpost_date":1349203393,"bandwidth":"57.63 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"sYLry","title":"IT'S UPSIDE DOWN GODDAMMIT","score":1914844,"size":65198,"views":114844,"datetime":"2012-10-02 18:39:47","mimetype":"image\/jpeg","ext":".jpg","width":160,"height":600,"ups":195,"downs":15,"points":180,"reddit":"\/r\/geek\/comments\/10tab8\/its_upside_down_goddammit\/","firstpost_date":1349203187,"bandwidth":"6.97 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"HaI3P","title":"The idiot bracelet.","score":2016249,"size":8789,"views":376249,"datetime":"2012-10-02 18:33:52","mimetype":"image\/jpeg","ext":".jpg","width":399,"height":276,"ups":206,"downs":42,"points":164,"reddit":"\/r\/funny\/comments\/10tcf2\/the_idiot_bracelet\/","firstpost_date":1349202832,"bandwidth":"3.08 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"1OfUO","title":"Don't judge us","score":5103279,"size":59297,"views":653279,"datetime":"2012-10-02 18:33:52","mimetype":"image\/jpeg","ext":".jpg","width":640,"height":480,"ups":448,"downs":3,"points":445,"reddit":"\/r\/pics\/comments\/10tlmf\/dont_judge_us\/","firstpost_date":1349202832,"bandwidth":"36.08 GB","source":"http:\/\/sphotos-a.xx.fbcdn.net\/hphotos-snc6\/185012_478170808869713_1208547211_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"BiQM1","title":"Fox cub rescued from hole caked in sludge and back to his adorable self","score":5948682,"size":206473,"views":338682,"datetime":"2012-10-02 18:28:29","mimetype":"image\/jpeg","ext":".jpg","width":1504,"height":721,"ups":565,"downs":4,"points":561,"reddit":"\/r\/PastAndPresentPics\/comments\/10sq1j\/fox_cub_rescued_from_hole_caked_in_sludge_and\/","firstpost_date":1349202509,"bandwidth":"65.13 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"6buuJ","title":"He looks happy","score":5284962,"size":28415,"views":244962,"datetime":"2012-10-02 18:02:51","mimetype":"image\/jpeg","ext":".jpg","width":400,"height":361,"ups":507,"downs":3,"points":504,"reddit":"\/r\/aww\/comments\/10t9hd\/he_looks_happy\/","firstpost_date":1349200971,"bandwidth":"6.48 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"6qcui","title":"forever astone.","score":4558657,"size":346484,"views":228657,"datetime":"2012-10-02 17:25:47","mimetype":"image\/jpeg","ext":".jpg","width":1920,"height":2560,"ups":437,"downs":4,"points":433,"reddit":"\/r\/pics\/comments\/10syt3\/forever_astone\/","firstpost_date":1349198747,"bandwidth":"73.78 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"0qM6o","title":"Expectations","score":5579819,"size":64026,"views":639819,"datetime":"2012-10-02 17:25:47","mimetype":"image\/jpeg","ext":".jpg","width":480,"height":395,"ups":506,"downs":12,"points":494,"reddit":"\/r\/funny\/comments\/10tf1s\/expectations\/","firstpost_date":1349198747,"bandwidth":"38.15 GB","source":"https:\/\/sphotos-a.xx.fbcdn.net\/hphotos-ash4\/s480x480\/385019_10152140040320557_154065151_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"tmOSR","title":"I, too, enjoyed the Fairly Odd Parents.","score":6599855,"size":636072,"views":489855,"datetime":"2012-10-02 17:10:00","mimetype":"image\/png","ext":".png","width":640,"height":479,"ups":620,"downs":9,"points":611,"reddit":"\/r\/funny\/comments\/10snl3\/i_too_enjoyed_the_fairly_odd_parents\/","firstpost_date":1349197800,"bandwidth":"290.18 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"g4qeS","title":"MFW my boyfriend made it on the front page with a pic I wanted to post...and then he told me today was also my cakeday.","score":3943150,"size":482485,"views":123150,"datetime":"2012-10-02 16:54:25","mimetype":"image\/gif","ext":".gif","width":245,"height":138,"ups":406,"downs":24,"points":382,"reddit":"\/r\/reactiongifs\/comments\/10rwv9\/mfw_my_boyfriend_made_it_on_the_front_page_with_a\/","firstpost_date":1349196865,"bandwidth":"55.34 GB","source":"http:\/\/media.tumblr.com\/tumblr_mb544nTl6s1rsqwi4.gif","gallery_timestamp":null,"vote":null},{"hash":"0555v","title":"So, my friend is doing a PhD... I'm getting worried.","score":5079153,"size":30082,"views":489153,"datetime":"2012-10-02 16:48:05","mimetype":"image\/jpeg","ext":".jpg","width":618,"height":144,"ups":487,"downs":28,"points":459,"reddit":"\/r\/funny\/comments\/10t9ly\/so_my_friend_is_doing_a_phd_im_getting_worried\/","firstpost_date":1349196485,"bandwidth":"13.70 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"GkLlr","title":"friend confuses girl enough to not talk to me","score":8343912,"size":164593,"views":373912,"datetime":"2012-10-02 16:43:39","mimetype":"image\/jpeg","ext":".jpg","width":460,"height":1732,"ups":820,"downs":23,"points":797,"reddit":"\/r\/funny\/comments\/10t56x\/friend_confuses_girl_enough_to_not_talk_to_me\/","firstpost_date":1349196219,"bandwidth":"57.32 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"E7koT","title":"Buddy of mine meet Liam Neeson..","score":8282719,"size":60846,"views":612719,"datetime":"2012-10-02 16:18:52","mimetype":"image\/png","ext":".png","width":521,"height":363,"ups":792,"downs":25,"points":767,"reddit":"\/r\/funny\/comments\/10tbxh\/buddy_of_mine_meet_liam_neeson\/","firstpost_date":1349194732,"bandwidth":"34.72 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"nMqZE","title":"Anne Hepburn (x-post from \/r\/GentlemanBoners)","score":4941233,"size":103910,"views":197229,"datetime":"2012-10-02 15:59:55","mimetype":"image\/jpeg","ext":".jpg","width":800,"height":1067,"ups":495,"downs":20,"points":475,"reddit":"\/r\/movies\/comments\/10t3xc\/anne_hepburn_xpost_from_rgentlemanboners\/","firstpost_date":1349193595,"bandwidth":"19.09 GB","source":"http:\/\/www.annehathaway.org.uk\/media\/photos\/annehathaway\/800_annehathaway-gq-288131899.jpg","gallery_timestamp":null,"vote":null},{"hash":"crvLc","title":"I found your ball.","score":6249325,"size":76345,"views":459325,"datetime":"2012-10-02 15:48:39","mimetype":"image\/jpeg","ext":".jpg","width":538,"height":720,"ups":587,"downs":8,"points":579,"reddit":"\/r\/aww\/comments\/10t86l\/i_found_your_ball\/","firstpost_date":1349192919,"bandwidth":"32.66 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Ppk0h","title":"So I opened the freezer at work...","score":4663207,"size":257508,"views":573207,"datetime":"2012-10-02 15:39:34","mimetype":"image\/jpeg","ext":".jpg","width":897,"height":1200,"ups":421,"downs":12,"points":409,"reddit":"\/r\/funny\/comments\/10t95s\/so_i_opened_the_freezer_at_work\/","firstpost_date":1349192374,"bandwidth":"137.47 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"OkT3r","title":"Baby Legendary Birds","score":4324155,"size":80065,"views":124155,"datetime":"2012-10-02 15:39:34","mimetype":"image\/jpeg","ext":".jpg","width":600,"height":500,"ups":433,"downs":13,"points":420,"reddit":"\/r\/pokemon\/comments\/10sl2r\/baby_legendary_birds\/","firstpost_date":1349192374,"bandwidth":"9.26 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"fhoQu","title":"Way to go Dad","score":4414964,"size":140448,"views":534964,"datetime":"2012-10-02 15:33:42","mimetype":"image\/jpeg","ext":".jpg","width":720,"height":1280,"ups":402,"downs":14,"points":388,"reddit":"\/r\/funny\/comments\/10s2tl\/way_to_go_dad\/","firstpost_date":1349192022,"bandwidth":"69.97 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"h0smi","title":"All he wanted was a cheeseburger","score":3561961,"size":97527,"views":551961,"datetime":"2012-10-02 15:23:37","mimetype":"image\/jpeg","ext":".jpg","width":467,"height":388,"ups":354,"downs":53,"points":301,"reddit":"\/r\/funny\/comments\/10t83z\/all_he_wanted_was_a_cheeseburger\/","firstpost_date":1349191417,"bandwidth":"50.13 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"sDrtw","title":"Just another self pic taken with a phone","score":6611544,"size":151507,"views":911544,"datetime":"2012-10-02 15:07:47","mimetype":"image\/jpeg","ext":".jpg","width":2048,"height":1536,"ups":589,"downs":19,"points":570,"reddit":"\/r\/funny\/comments\/10td3s\/just_another_self_pic_taken_with_a_phone\/","firstpost_date":1349190467,"bandwidth":"128.62 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Yhnzv","title":"Thought you guys would appreciate what my employee had made!","score":6586777,"size":42361,"views":506777,"datetime":"2012-10-02 14:39:11","mimetype":"image\/jpeg","ext":".jpg","width":909,"height":864,"ups":647,"downs":39,"points":608,"reddit":"\/r\/POLITIC\/comments\/10si75\/thought_you_guys_would_appreciate_what_my\/","firstpost_date":1349188751,"bandwidth":"19.99 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"JfniQ","title":"If you know what I mean...","score":4644116,"size":19123,"views":304116,"datetime":"2012-10-02 14:27:37","mimetype":"image\/jpeg","ext":".jpg","width":480,"height":351,"ups":472,"downs":38,"points":434,"reddit":"\/r\/funny\/comments\/10st3v\/if_you_know_what_i_mean\/","firstpost_date":1349188057,"bandwidth":"5.42 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"OJG7o","title":"Noticed there was some writing on this SUV when I was on my way to work this morning, then I read it and was immediately in a better mood.","score":10553385,"size":114969,"views":583385,"datetime":"2012-10-02 14:18:28","mimetype":"image\/jpeg","ext":".jpg","width":1224,"height":690,"ups":1007,"downs":10,"points":997,"reddit":"\/r\/aww\/comments\/10s8x3\/noticed_there_was_some_writing_on_this_suv_when_i\/","firstpost_date":1349187508,"bandwidth":"62.46 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"C260R","title":"My Costume so far","score":4783063,"size":369154,"views":143063,"datetime":"2012-10-02 14:18:28","mimetype":"image\/jpeg","ext":".jpg","width":897,"height":1200,"ups":494,"downs":30,"points":464,"reddit":"\/r\/batman\/comments\/10rpmm\/my_costume_so_far\/","firstpost_date":1349187508,"bandwidth":"49.19 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"8q5zf","title":"If you mention One Direction one more time.....","score":1921503,"size":5220,"views":471503,"datetime":"2012-10-02 14:13:59","mimetype":"image\/png","ext":".png","width":524,"height":194,"ups":389,"downs":244,"points":145,"reddit":"\/r\/funny\/comments\/10sn5h\/if_you_mention_one_direction_one_more_time\/","firstpost_date":1349187239,"bandwidth":"2.29 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"3nI55","title":"Rob Ryan of the Cowboys has a classy message for Colt's Coach Pagano","score":2208227,"size":716346,"views":158227,"datetime":"2012-10-02 14:13:59","mimetype":"image\/jpeg","ext":".jpg","width":2448,"height":3264,"ups":217,"downs":12,"points":205,"reddit":"\/r\/nfl\/comments\/10slkx\/rob_ryan_of_the_cowboys_has_a_classy_message_for\/","firstpost_date":1349187239,"bandwidth":"105.56 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"klwRO","title":"The cutest alcoholic ever.","score":3086602,"size":341418,"views":355702,"datetime":"2012-10-02 14:02:19","mimetype":"image\/jpeg","ext":".jpg","width":1200,"height":1200,"ups":304,"downs":30,"points":274,"reddit":"\/r\/aww\/comments\/10rjer\/the_cutest_alcoholic_ever\/","firstpost_date":1349186539,"bandwidth":"113.10 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"nkVFN","title":"Emily Deschanel on sister Zooey.","score":8979496,"size":263075,"views":504872,"datetime":"2012-10-02 13:51:30","mimetype":"image\/png","ext":".png","width":502,"height":560,"ups":864,"downs":16,"points":848,"reddit":"\/r\/funny\/comments\/10szmv\/emily_deschanel_on_sister_zooey\/","firstpost_date":1349185890,"bandwidth":"123.70 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"CM2aX","title":"So I was eating at grandmas..when this popped out from under the table..","score":7823912,"size":99848,"views":473912,"datetime":"2012-10-02 13:17:55","mimetype":"image\/jpeg","ext":".jpg","width":869,"height":1023,"ups":751,"downs":16,"points":735,"reddit":"\/r\/funny\/comments\/10sq71\/so_i_was_eating_at_grandmaswhen_this_popped_out\/","firstpost_date":1349183875,"bandwidth":"44.07 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Z64wz","title":"Almost Politically Correct Redneck on Psy","score":6944598,"size":127781,"views":604598,"datetime":"2012-10-02 13:13:16","mimetype":"image\/jpeg","ext":".jpg","width":400,"height":400,"ups":653,"downs":19,"points":634,"reddit":"\/r\/AdviceAnimals\/comments\/10ssla\/almost_politically_correct_redneck_on_psy\/","firstpost_date":1349183596,"bandwidth":"71.95 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"JXrA9","title":"If only I had this as a kid....","score":5913358,"size":21612,"views":903358,"datetime":"2012-10-02 13:13:16","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":401,"ups":507,"downs":6,"points":501,"reddit":"\/r\/pics\/comments\/10t52u\/if_only_i_had_this_as_a_kid\/","firstpost_date":1349183596,"bandwidth":"18.18 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Rd3hr","title":"My friends mom is in the hospital due to brain cancer. Her husband sleeps on the floor to be with her.","score":8382913,"size":84232,"views":332913,"datetime":"2012-10-02 12:59:53","mimetype":"image\/jpeg","ext":".jpg","width":1024,"height":1024,"ups":813,"downs":8,"points":805,"reddit":"\/r\/aww\/comments\/10svoe\/my_friends_mom_is_in_the_hospital_due_to_brain\/","firstpost_date":1349182793,"bandwidth":"26.12 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"iyI4C","title":"Today I went up into the new World Trade Center.","score":6189066,"size":512259,"views":429066,"datetime":"2012-10-02 12:59:53","mimetype":"image\/jpeg","ext":".jpg","width":2592,"height":1936,"ups":581,"downs":5,"points":576,"reddit":"\/r\/pics\/comments\/10srz0\/today_i_went_up_into_the_new_world_trade_center\/","firstpost_date":1349182793,"bandwidth":"204.70 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"kQ2qH","title":"Amazing supercell pano","score":7982025,"size":46027,"views":331812,"datetime":"2012-10-02 12:45:30","mimetype":"image\/jpeg","ext":".jpg","width":1200,"height":440,"ups":768,"downs":2,"points":766,"reddit":"\/r\/pics\/comments\/10rns7\/amazing_supercell_pano\/","firstpost_date":1349181930,"bandwidth":"14.22 GB","source":"http:\/\/sphotos-a.xx.fbcdn.net\/hphotos-snc6\/258207_10151116836521985_307345447_o.jpg","gallery_timestamp":null,"vote":null},{"hash":"F8hFH","title":"My Uncle Dutch has a Facebook account that he posts regularly from.  Problem is he's been dead for a few months now.  Facebook app \"Truth About You\" posting links through user accounts without user permission.","score":2085535,"size":90995,"views":175535,"datetime":"2012-10-02 12:38:20","mimetype":"image\/jpeg","ext":".jpg","width":850,"height":627,"ups":226,"downs":35,"points":191,"reddit":"\/r\/technology\/comments\/10su7a\/my_uncle_dutch_has_a_facebook_account_that_he\/","firstpost_date":1349181500,"bandwidth":"14.88 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"vw5vJ","title":"First Pagani in the United States!","score":7381184,"size":657886,"views":151184,"datetime":"2012-10-02 12:34:15","mimetype":"image\/jpeg","ext":".jpg","width":1200,"height":1200,"ups":740,"downs":17,"points":723,"reddit":"\/r\/TopGear\/comments\/10skcc\/first_pagani_in_the_united_states\/","firstpost_date":1349181255,"bandwidth":"92.63 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"UC8u5","title":"Who needs a cat anyway?","score":8741839,"size":989012,"views":761839,"datetime":"2012-10-02 12:34:15","mimetype":"image\/gif","ext":".gif","width":499,"height":278,"ups":801,"downs":3,"points":798,"reddit":"\/r\/funny\/comments\/10t2gw\/who_needs_a_cat_anyway\/","firstpost_date":1349181255,"bandwidth":"701.72 GB","source":"http:\/\/h10.abload.de\/img\/tumblr_m1nm5knbmu1qfjvzrqa.gif","gallery_timestamp":null,"vote":null},{"hash":"JbELw","title":"Aussie facebook gold...","score":7777162,"size":116601,"views":667162,"datetime":"2012-10-02 12:12:52","mimetype":"image\/png","ext":".png","width":720,"height":978,"ups":750,"downs":39,"points":711,"reddit":"\/r\/funny\/comments\/10t3n8\/aussie_facebook_gold\/","firstpost_date":1349179972,"bandwidth":"72.45 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Z4Sdl","title":"Education system","score":6343801,"size":344753,"views":293801,"datetime":"2012-10-02 11:47:46","mimetype":"image\/png","ext":".png","width":632,"height":469,"ups":647,"downs":42,"points":605,"reddit":"\/r\/funny\/comments\/10sa3o\/education_system\/","firstpost_date":1349178466,"bandwidth":"94.33 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"HhlqS","title":"How to be a gentleman","score":5967822,"size":25302,"views":517822,"datetime":"2012-10-02 11:47:46","mimetype":"image\/jpeg","ext":".jpg","width":403,"height":167,"ups":565,"downs":20,"points":545,"reddit":"\/r\/funny\/comments\/10sm6m\/how_to_be_a_gentleman\/","firstpost_date":1349178466,"bandwidth":"12.20 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"UljCK","title":"Here comes the train!","score":9162536,"size":110072,"views":542536,"datetime":"2012-10-02 11:29:16","mimetype":"image\/jpeg","ext":".jpg","width":612,"height":612,"ups":876,"downs":14,"points":862,"reddit":"\/r\/funny\/comments\/10srv9\/here_comes_the_train\/","firstpost_date":1349177356,"bandwidth":"55.62 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"DPdNk","title":"My girlfriend left her phone unattended.","score":7675041,"size":150641,"views":365041,"datetime":"2012-10-02 11:17:43","mimetype":"image\/jpeg","ext":".jpg","width":381,"height":1373,"ups":752,"downs":21,"points":731,"reddit":"\/r\/funny\/comments\/10sean\/my_girlfriend_left_her_phone_unattended\/","firstpost_date":1349176663,"bandwidth":"51.21 GB","source":"http:\/\/i.imgur.com\/ojrn6.jpg","gallery_timestamp":null,"vote":null},{"hash":"tL78A","title":"Behold, McDonalds eggs before being 'cooked'","score":4335246,"size":60689,"views":505246,"datetime":"2012-10-02 11:12:24","mimetype":"image\/jpeg","ext":".jpg","width":1024,"height":764,"ups":427,"downs":44,"points":383,"reddit":"\/r\/pics\/comments\/10suwl\/behold_mcdonalds_eggs_before_being_cooked\/","firstpost_date":1349176344,"bandwidth":"28.56 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"DPCmq","title":"camouflage expert level 100","score":7403604,"size":15100,"views":433604,"datetime":"2012-10-02 11:04:44","mimetype":"image\/jpeg","ext":".jpg","width":340,"height":325,"ups":702,"downs":5,"points":697,"reddit":"\/r\/funny\/comments\/10rhb7\/camouflage_expert_level_100\/","firstpost_date":1349175884,"bandwidth":"6.10 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"cB58w","title":"Amazing Wood Sculpture","score":9499521,"size":53445,"views":369521,"datetime":"2012-10-02 10:49:44","mimetype":"image\/jpeg","ext":".jpg","width":768,"height":1024,"ups":919,"downs":6,"points":913,"reddit":"\/r\/pics\/comments\/10sj2a\/amazing_wood_sculpture\/","firstpost_date":1349174984,"bandwidth":"18.39 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"eMaax","title":"Emma Watson","score":11990001,"size":27867,"views":510001,"datetime":"2012-10-02 10:29:02","mimetype":"image\/jpeg","ext":".jpg","width":400,"height":497,"ups":1199,"downs":51,"points":1148,"reddit":"\/r\/pics\/comments\/10stx5\/emma_watson\/","firstpost_date":1349173742,"bandwidth":"13.24 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"N0b8b","title":"TIL Magnitude (Lee Jordan) began as the high pitched commentator in Harry Potter and the Philosopher's Stone","score":4385377,"size":15295,"views":145377,"datetime":"2012-10-02 09:35:20","mimetype":"image\/jpeg","ext":".jpg","width":321,"height":240,"ups":439,"downs":15,"points":424,"reddit":"\/r\/community\/comments\/10rlqm\/til_magnitude_lee_jordan_began_as_the_high\/","firstpost_date":1349170520,"bandwidth":"2.07 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"DRjbQ","title":"I'm pretty proud of this one.","score":10171153,"size":720341,"views":601153,"datetime":"2012-10-02 09:35:20","mimetype":"image\/jpeg","ext":".jpg","width":4320,"height":3240,"ups":968,"downs":11,"points":957,"reddit":"\/r\/funny\/comments\/10sd3f\/im_pretty_proud_of_this_one\/","firstpost_date":1349170520,"bandwidth":"403.30 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"g5gGE","title":"Look what you guys have done again AGAIN","score":9730868,"size":97987,"views":670868,"datetime":"2012-10-02 08:57:25","mimetype":"image\/png","ext":".png","width":850,"height":348,"ups":921,"downs":15,"points":906,"reddit":"\/r\/funny\/comments\/10sphh\/look_what_you_guys_have_done_again_again\/","firstpost_date":1349168245,"bandwidth":"61.22 GB","source":"http:\/\/s3.amazonaws.com\/awesome_screenshot\/831543?AWSAccessKeyId=0R7FMW7AXRVCYMAPTPR2&Expires=1349146967&Signature=DMIGBIF8qAjx2AO0BvROOBbntuo%3D","gallery_timestamp":null,"vote":null},{"hash":"KOqow","title":"Guy came to class dressed like Gerald","score":7924746,"size":473978,"views":374746,"datetime":"2012-10-02 08:55:43","mimetype":"image\/png","ext":".png","width":480,"height":800,"ups":766,"downs":11,"points":755,"reddit":"\/r\/pics\/comments\/10sa2a\/guy_came_to_class_dressed_like_gerald\/","firstpost_date":1349168143,"bandwidth":"165.42 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"Y4Ch5","title":"My son is making a new religion","score":4324500,"size":58393,"views":434500,"datetime":"2012-10-02 08:34:52","mimetype":"image\/jpeg","ext":".jpg","width":663,"height":490,"ups":416,"downs":27,"points":389,"reddit":"\/r\/funny\/comments\/10sez0\/my_son_is_making_a_new_religion\/","firstpost_date":1349166892,"bandwidth":"23.63 GB","source":"http:\/\/sphotos-b.xx.fbcdn.net\/hphotos-snc7\/401380_410145765706144_2064020088_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"PJd8f","title":"How I do the sex","score":5218008,"size":2068061,"views":308008,"datetime":"2012-10-02 08:24:16","mimetype":"image\/gif","ext":".gif","width":330,"height":185,"ups":523,"downs":32,"points":491,"reddit":"\/r\/gifs\/comments\/10shv1\/how_i_do_the_sex\/","firstpost_date":1349166256,"bandwidth":"593.23 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ufSVR","title":"Life Isn't Fair.","score":10144020,"size":39592,"views":314020,"datetime":"2012-10-02 07:48:40","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":371,"ups":993,"downs":10,"points":983,"reddit":"\/r\/funny\/comments\/10s10h\/life_isnt_fair\/","firstpost_date":1349164120,"bandwidth":"11.58 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"xSU1P","title":"Bike parts skyline.","score":6299291,"size":62221,"views":299291,"datetime":"2012-10-02 07:42:47","mimetype":"image\/jpeg","ext":".jpg","width":1000,"height":406,"ups":603,"downs":3,"points":600,"reddit":"\/r\/pics\/comments\/10rzu5\/bike_parts_skyline\/","firstpost_date":1349163767,"bandwidth":"17.34 GB","source":"http:\/\/24.media.tumblr.com\/tumblr_mb85ncDHYG1qz6f9yo1_1280.jpg","gallery_timestamp":null,"vote":null},{"hash":"sNhds","title":"Bazinga.","score":7125676,"size":17286,"views":255676,"datetime":"2012-10-02 07:42:47","mimetype":"image\/jpeg","ext":".jpg","width":300,"height":168,"ups":759,"downs":72,"points":687,"reddit":"\/r\/funny\/comments\/10sp7x\/bazinga\/","firstpost_date":1349163767,"bandwidth":"4.12 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"GIF7N","title":"After Questing all the way to 90, i thought i was having a nightmare in my local mall!","score":2870506,"size":87192,"views":160506,"datetime":"2012-10-02 07:33:11","mimetype":"image\/jpeg","ext":".jpg","width":720,"height":960,"ups":313,"downs":42,"points":271,"reddit":"\/r\/wow\/comments\/10riwc\/after_questing_all_the_way_to_90_i_thought_i_was\/","firstpost_date":1349163191,"bandwidth":"13.03 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"SddiL","title":"Friends come in any size","score":7282858,"size":66896,"views":222858,"datetime":"2012-10-02 07:23:30","mimetype":"image\/jpeg","ext":".jpg","width":960,"height":720,"ups":714,"downs":8,"points":706,"reddit":"\/r\/aww\/comments\/10rx27\/friends_come_in_any_size\/","firstpost_date":1349162610,"bandwidth":"13.88 GB","source":"https:\/\/sphotos-a.xx.fbcdn.net\/hphotos-snc6\/228094_10151055887910981_1314395040_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"pgnQa","title":"Fat creepy dude kept staring at me at the gym ","score":9926813,"size":23171,"views":316813,"datetime":"2012-10-02 07:23:30","mimetype":"image\/jpeg","ext":".jpg","width":481,"height":166,"ups":988,"downs":27,"points":961,"reddit":"\/r\/funny\/comments\/10snwk\/fat_creepy_dude_kept_staring_at_me_at_the_gym_fb\/","firstpost_date":1349162610,"bandwidth":"6.84 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"I0Ox6","title":"One of my favorite types of sorcery...I mean illusions","score":11070357,"size":347757,"views":480357,"datetime":"2012-10-02 07:14:09","mimetype":"image\/gif","ext":".gif","width":640,"height":480,"ups":1083,"downs":24,"points":1059,"reddit":"\/r\/pics\/comments\/10s5u6\/one_of_my_favorite_types_of_sorceryi_mean\/","firstpost_date":1349162049,"bandwidth":"155.58 GB","source":"http:\/\/img.izismile.com\/img\/img2\/20090618\/illusion.gif","gallery_timestamp":null,"vote":null},{"hash":"EW5a2","title":"My cat, Cuss, is an avid fan of this.","score":8334788,"size":53393,"views":284788,"datetime":"2012-10-02 07:03:38","mimetype":"image\/jpeg","ext":".jpg","width":500,"height":338,"ups":825,"downs":20,"points":805,"reddit":"\/r\/AdviceAnimals\/comments\/10s2tf\/my_cat_cuss_is_an_avid_fan_of_this\/","firstpost_date":1349161418,"bandwidth":"14.16 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"9jKqz","title":"My little sister's school had Dress as Your Hero day. Some kids went as princesses or firemen. She went as someone... different.","score":7231905,"size":284979,"views":251905,"datetime":"2012-10-02 06:58:02","mimetype":"image\/jpeg","ext":".jpg","width":764,"height":1024,"ups":710,"downs":12,"points":698,"reddit":"\/r\/pics\/comments\/10rt5a\/my_little_sisters_school_had_dress_as_your_hero\/","firstpost_date":1349161082,"bandwidth":"66.86 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"7bOfP","title":"I went to go change the sprinkler and start the grill... I think he knows he screwed up.","score":5620851,"size":487356,"views":210851,"datetime":"2012-10-02 06:54:56","mimetype":"image\/jpeg","ext":".jpg","width":1536,"height":2048,"ups":549,"downs":8,"points":541,"reddit":"\/r\/aww\/comments\/10rqzw\/i_went_to_go_change_the_sprinkler_and_start_the\/","firstpost_date":1349160896,"bandwidth":"95.70 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"W3jj9","title":"Friends new iPhone. Special Delivery...","score":12995503,"size":101257,"views":845503,"datetime":"2012-10-02 06:28:30","mimetype":"image\/jpeg","ext":".jpg","width":541,"height":960,"ups":1231,"downs":16,"points":1215,"reddit":"\/r\/funny\/comments\/10skd6\/friends_new_iphone_special_delivery\/","firstpost_date":1349159310,"bandwidth":"79.73 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"zby0C","title":"Revenge","score":5424900,"size":300713,"views":224900,"datetime":"2012-10-02 06:24:53","mimetype":"image\/jpeg","ext":".jpg","width":1279,"height":1644,"ups":611,"downs":91,"points":520,"reddit":"\/r\/4chan\/comments\/10r5hn\/revenge\/","firstpost_date":1349159093,"bandwidth":"62.99 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"iUOA1","title":"The Refs had a message for the fans before the Monday Night game tonight!","score":7326354,"size":222635,"views":266354,"datetime":"2012-10-02 06:24:53","mimetype":"image\/jpeg","ext":".jpg","width":800,"height":600,"ups":747,"downs":41,"points":706,"reddit":"\/r\/nfl\/comments\/10sevr\/the_refs_had_a_message_for_the_fans_before_the\/","firstpost_date":1349159093,"bandwidth":"55.23 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"J1uAd","title":"And that, kids, is how I met your mother. (FB)","score":8789365,"size":15121,"views":809365,"datetime":"2012-10-02 06:18:12","mimetype":"image\/png","ext":".png","width":405,"height":318,"ups":865,"downs":67,"points":798,"reddit":"\/r\/funny\/comments\/10smbg\/and_that_kids_is_how_i_met_your_mother_fb\/","firstpost_date":1349158692,"bandwidth":"11.40 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"mkp0y","title":"I haven't looked back yet.","score":4259182,"size":96308,"views":278070,"datetime":"2012-10-02 06:14:43","mimetype":"image\/jpeg","ext":".jpg","width":400,"height":400,"ups":408,"downs":9,"points":399,"reddit":"\/r\/AdviceAnimals\/comments\/10rvub\/i_havent_looked_back_yet\/","firstpost_date":1349158483,"bandwidth":"24.94 GB","source":"http:\/\/cdn.memegenerator.net\/instances\/400x\/27650883.jpg","gallery_timestamp":null,"vote":null},{"hash":"cWwvj","title":"Like a trooper.","score":6901509,"size":64320,"views":381509,"datetime":"2012-10-02 06:03:16","mimetype":"image\/png","ext":".png","width":464,"height":184,"ups":698,"downs":46,"points":652,"reddit":"\/r\/funny\/comments\/10s1h9\/like_a_trooper\/","firstpost_date":1349157796,"bandwidth":"22.85 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"OMXDT","title":"Siri... I'm starting to worry about you...","score":3094834,"size":254341,"views":164834,"datetime":"2012-10-02 05:50:20","mimetype":"image\/jpeg","ext":".jpg","width":640,"height":1136,"ups":303,"downs":10,"points":293,"reddit":"\/r\/iphone\/comments\/10rhm0\/siri_im_starting_to_worry_about_you\/","firstpost_date":1349157020,"bandwidth":"39.04 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"W7F3E","title":"Cutest monkey in the world, looks like a cross between a chinchilla and a monkey.","score":10351991,"size":37178,"views":241991,"datetime":"2012-10-02 05:29:02","mimetype":"image\/jpeg","ext":".jpg","width":615,"height":410,"ups":1020,"downs":9,"points":1011,"reddit":"\/r\/aww\/comments\/10rs0j\/cutest_monkey_in_the_world_looks_like_a_cross\/","firstpost_date":1349155742,"bandwidth":"8.38 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"B4lZe","title":"It's okay, I got this!","score":6435172,"size":1022248,"views":375172,"datetime":"2012-10-02 05:29:02","mimetype":"image\/gif","ext":".gif","width":500,"height":269,"ups":610,"downs":4,"points":606,"reddit":"\/r\/funny\/comments\/10r9rj\/its_okay_i_got_this\/","firstpost_date":1349155742,"bandwidth":"357.18 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"9qzH0","title":"Look who I found on Chat Roulette.","score":6142969,"size":373110,"views":302969,"datetime":"2012-10-02 05:29:01","mimetype":"image\/png","ext":".png","width":1280,"height":800,"ups":599,"downs":15,"points":584,"reddit":"\/r\/pics\/comments\/10s62z\/look_who_i_found_on_chat_roulette\/","firstpost_date":1349155741,"bandwidth":"105.28 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"YAkId","title":"My friend recently surpassed me in karma,using her cat, I don't have a cat. But, I do have a pic of her as a cat, when she was little.","score":5502846,"size":27601,"views":312846,"datetime":"2012-10-02 04:49:34","mimetype":"image\/jpeg","ext":".jpg","width":768,"height":1024,"ups":542,"downs":23,"points":519,"reddit":"\/r\/funny\/comments\/10sk48\/my_friend_recently_surpassed_me_in_karmausing_her\/","firstpost_date":1349153374,"bandwidth":"8.04 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"08OM1","title":"They need a hero.","score":12930120,"size":509811,"views":540120,"datetime":"2012-10-02 04:38:54","mimetype":"image\/gif","ext":".gif","width":375,"height":211,"ups":1248,"downs":9,"points":1239,"reddit":"\/r\/funny\/comments\/10rzvl\/they_need_a_hero\/","firstpost_date":1349152734,"bandwidth":"256.45 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"j62TV","title":"Impressive Youtube Commenter is impressive","score":10271623,"size":318903,"views":581623,"datetime":"2012-10-02 04:33:19","mimetype":"image\/png","ext":".png","width":797,"height":544,"ups":1026,"downs":57,"points":969,"reddit":"\/r\/funny\/comments\/10rxr3\/impressive_youtube_commenter_is_impressive\/","firstpost_date":1349152399,"bandwidth":"172.74 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"IejlW","title":"Glock underwater","score":8496712,"size":2586590,"views":326712,"datetime":"2012-10-02 04:23:41","mimetype":"image\/gif","ext":".gif","width":320,"height":240,"ups":826,"downs":9,"points":817,"reddit":"\/r\/gifs\/comments\/10s1rp\/glock_underwater\/","firstpost_date":1349151821,"bandwidth":"787.03 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"bBvNF","title":"Holding Doors.","score":8217631,"size":96552,"views":347631,"datetime":"2012-10-02 04:17:46","mimetype":"image\/jpeg","ext":".jpg","width":720,"height":1129,"ups":800,"downs":13,"points":787,"reddit":"\/r\/funny\/comments\/10rxvh\/holding_doors\/","firstpost_date":1349151466,"bandwidth":"31.26 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"82K6i","title":"Don't mind me, I'm just hugging my buddy!","score":9436078,"size":56632,"views":366078,"datetime":"2012-10-02 04:15:19","mimetype":"image\/jpeg","ext":".jpg","width":784,"height":501,"ups":917,"downs":10,"points":907,"reddit":"\/r\/aww\/comments\/10rljb\/dont_mind_me_im_just_hugging_my_buddy\/","firstpost_date":1349151319,"bandwidth":"19.31 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"VPjn9","title":"Annnnnnnnd this is by far the coolest bed(nest) i have seen.","score":12677673,"size":182852,"views":287673,"datetime":"2012-10-02 03:53:38","mimetype":"image\/jpeg","ext":".jpg","width":1280,"height":1024,"ups":1249,"downs":10,"points":1239,"reddit":"\/r\/pics\/comments\/10reo0\/annnnnnnnd_this_is_by_far_the_coolest_bednest_i\/","firstpost_date":1349150018,"bandwidth":"48.99 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"ivrDk","title":"Burning Man ignited by a huge Tesla Coil","score":9464374,"size":232812,"views":474374,"datetime":"2012-10-02 03:33:31","mimetype":"image\/jpeg","ext":".jpg","width":900,"height":675,"ups":907,"downs":8,"points":899,"reddit":"\/r\/pics\/comments\/10rsms\/burning_man_ignited_by_a_huge_tesla_coil\/","firstpost_date":1349148811,"bandwidth":"102.86 GB","source":"http:\/\/pcdn.500px.net\/12708159\/c504a6c61e0ef0891b7103a4f2d655f2d440bb91\/4.jpg","gallery_timestamp":null,"vote":null},{"hash":"by28m","title":"The are repaving the parking lot at work","score":4825497,"size":114082,"views":535497,"datetime":"2012-10-02 03:33:31","mimetype":"image\/jpeg","ext":".jpg","width":960,"height":541,"ups":436,"downs":7,"points":429,"reddit":"\/r\/pics\/comments\/10rub8\/the_are_repaving_the_parking_lot_at_work\/","firstpost_date":1349148811,"bandwidth":"56.90 GB","source":"https:\/\/sphotos-b.xx.fbcdn.net\/hphotos-prn1\/523135_955429030680_1858916364_n.jpg","gallery_timestamp":null,"vote":null},{"hash":"PEmJe","title":"My Pirate Cat Cheese when he was still a kitten","score":10045369,"size":112109,"views":295369,"datetime":"2012-10-02 03:18:11","mimetype":"image\/jpeg","ext":".jpg","width":576,"height":768,"ups":995,"downs":20,"points":975,"reddit":"\/r\/aww\/comments\/10rl2c\/my_pirate_cat_cheese_when_he_was_still_a_kitten\/","firstpost_date":1349147891,"bandwidth":"30.84 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"wszW2","title":"That's not a foot!","score":5587507,"size":598299,"views":487507,"datetime":"2012-10-02 03:13:44","mimetype":"image\/jpeg","ext":".jpg","width":2560,"height":1440,"ups":527,"downs":17,"points":510,"reddit":"\/r\/pics\/comments\/10rrco\/thats_not_a_foot\/","firstpost_date":1349147624,"bandwidth":"271.64 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"KtUjb","title":"How I feel after celebrating my five year anniversary with the same employer","score":9072626,"size":39726,"views":702626,"datetime":"2012-10-02 02:53:47","mimetype":"image\/jpeg","ext":".jpg","width":552,"height":414,"ups":843,"downs":6,"points":837,"reddit":"\/r\/AdviceAnimals\/comments\/10rw93\/how_i_feel_after_celebrating_my_five_year\/","firstpost_date":1349146427,"bandwidth":"26.00 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"X8oEW","title":"Happy autumn everyone! Here's a \"natural\" Canadian flag, with more in the comments.","score":13475646,"size":135216,"views":575646,"datetime":"2012-10-02 02:43:24","mimetype":"image\/jpeg","ext":".jpg","width":1024,"height":512,"ups":1306,"downs":16,"points":1290,"reddit":"\/r\/POLITIC\/comments\/10r7ki\/happy_autumn_everyone_heres_a_natural_canadian\/","firstpost_date":1349145804,"bandwidth":"72.49 GB","source":"http:\/\/www.donkom.ca\/wp-content\/uploads\/2011\/07\/leaf_flag_1200x600_wm-1024x512.jpg","gallery_timestamp":null,"vote":null},{"hash":"p0Sny","title":"for those of us with shitty internet connections ","score":4188313,"size":56791,"views":518313,"datetime":"2012-10-02 02:43:24","mimetype":"image\/png","ext":".png","width":821,"height":532,"ups":383,"downs":16,"points":367,"reddit":"\/r\/funny\/comments\/10rqo8\/for_those_of_us_with_shitty_internet_connections\/","firstpost_date":1349145804,"bandwidth":"27.41 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"HUxVm","title":"So, this guy was running in the Crescent City Classic","score":8040920,"size":195282,"views":490920,"datetime":"2012-10-02 02:08:36","mimetype":"image\/jpeg","ext":".jpg","width":2048,"height":1366,"ups":765,"downs":10,"points":755,"reddit":"\/r\/pics\/comments\/10rjk8\/so_this_guy_was_running_in_the_crescent_city\/","firstpost_date":1349143716,"bandwidth":"89.28 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"d4pzM","title":"damn! got a piece of gum stuck to my head","score":8501946,"size":323520,"views":311946,"datetime":"2012-10-02 01:26:24","mimetype":"image\/jpeg","ext":".jpg","width":743,"height":855,"ups":840,"downs":21,"points":819,"reddit":"\/r\/skyrim\/comments\/10rcob\/damn_got_a_piece_of_gum_stuck_to_my_head\/","firstpost_date":1349141184,"bandwidth":"93.99 GB","source":"http:\/\/cache.ilbe.com\/files\/attach\/images\/377678\/383\/175\/233\/ccacd82245e744a67f880347530e1fff.jpg","gallery_timestamp":null,"vote":null},{"hash":"b6AA3","title":"Tiny hugs \u2665","score":10708007,"size":40479,"views":368007,"datetime":"2012-10-02 01:05:34","mimetype":"image\/jpeg","ext":".jpg","width":400,"height":589,"ups":1043,"downs":9,"points":1034,"reddit":"\/r\/aww\/comments\/10rlnw\/tiny_hugs\/","firstpost_date":1349139934,"bandwidth":"13.87 GB","source":"http:\/\/25.media.tumblr.com\/tumblr_lae9lyeEAN1qepyl8o1_400.jpg","gallery_timestamp":null,"vote":null},{"hash":"SCqtX","title":"Scarlett Johansson","score":18681909,"size":500758,"views":1051909,"datetime":"2012-10-02 00:53:20","mimetype":"image\/jpeg","ext":".jpg","width":1234,"height":1600,"ups":1836,"downs":73,"points":1763,"reddit":"\/r\/pics\/comments\/10s052\/scarlett_johansson\/","firstpost_date":1349139200,"bandwidth":"490.58 GB","source":"http:\/\/25.media.tumblr.com\/tumblr_maxjumVhuX1qz9qooo1_1280.jpg","gallery_timestamp":null,"vote":null},{"hash":"Vnz2c","title":"We arrived at our campsite before our friend. He asked us not to touch his beer. He received this photo in return.","score":10691953,"size":575705,"views":541953,"datetime":"2012-10-02 00:49:43","mimetype":"image\/jpeg","ext":".jpg","width":1936,"height":2592,"ups":1047,"downs":32,"points":1015,"reddit":"\/r\/pics\/comments\/10rnsi\/we_arrived_at_our_campsite_before_our_friend_he\/","firstpost_date":1349138983,"bandwidth":"290.58 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"QDlkP","title":"\"Oh mah gawsh!! Your home!! I'm sooooo happy to see you!\"","score":11590881,"size":320111,"views":330881,"datetime":"2012-10-02 00:49:43","mimetype":"image\/jpeg","ext":".jpg","width":1708,"height":1936,"ups":1171,"downs":45,"points":1126,"reddit":"\/r\/aww\/comments\/10rj52\/oh_mah_gawsh_your_home_im_sooooo_happy_to_see_you\/","firstpost_date":1349138983,"bandwidth":"98.64 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"OZaO1","title":"Canada got it right.","score":14432913,"size":454459,"views":522913,"datetime":"2012-10-02 00:49:27","mimetype":"image\/jpeg","ext":".jpg","width":1600,"height":1200,"ups":1438,"downs":47,"points":1391,"reddit":"\/r\/pics\/comments\/10romz\/canada_got_it_right\/","firstpost_date":1349138967,"bandwidth":"221.32 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"3SWtv","title":"I put an Obama 2012 sticker on my car and after work this was on my window. (X-post r\/funny)","score":7382260,"size":695662,"views":1182260,"datetime":"2012-10-02 00:49:26","mimetype":"image\/jpeg","ext":".jpg","width":2591,"height":1935,"ups":875,"downs":255,"points":620,"reddit":"\/r\/pics\/comments\/10s1om\/i_put_an_obama_2012_sticker_on_my_car_and_after\/","firstpost_date":1349138966,"bandwidth":"765.97 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"JIKKy","title":"Yeah ladies, we know what you want ;)","score":8897281,"size":209327,"views":577281,"datetime":"2012-10-02 00:43:39","mimetype":"image\/jpeg","ext":".jpg","width":700,"height":937,"ups":901,"downs":69,"points":832,"reddit":"\/r\/pics\/comments\/10rmn1\/yeah_ladies_we_know_what_you_want\/","firstpost_date":1349138619,"bandwidth":"112.54 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"IaWXM","title":"If you park like this, you are an ass!","score":6393127,"size":33255,"views":453127,"datetime":"2012-10-02 00:43:38","mimetype":"image\/jpeg","ext":".jpg","width":360,"height":480,"ups":603,"downs":9,"points":594,"reddit":"\/r\/funny\/comments\/10rfwu\/if_you_park_like_this_you_are_an_ass\/","firstpost_date":1349138618,"bandwidth":"14.03 GB","source":null,"gallery_timestamp":null,"vote":null},{"hash":"BKJYv","title":"Now show me your GRR face!","score":11216834,"size":23687,"views":266834,"datetime":"2012-10-02 00:35:57","mimetype":"image\/jpeg","ext":".jpg","width":360,"height":426,"ups":1120,"downs":25,"points":1095,"reddit":"\/r\/aww\/comments\/10rrie\/now_show_me_your_grr_face\/","firstpost_date":1349138157,"bandwidth":"5.89 GB","source":null,"gallery_timestamp":null,"vote":null}]};
    for(var i = 0; i < IMAGES.options.data.gallery.length; ++i) {
        IMAGES.options.data.gallery[i].likes = [];
        IMAGES.options.data.gallery[i].comments = [];
    }
    $('#photos').html(IMAGES.render().el);
}

});